/**
 * Copyright (c) 2024 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_WSTD_3Q.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_WSTD_3Q *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_WSTD_3Q_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_3Q));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_3Q(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_WSTD_3Q_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_3Q));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_3Q(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_WSTD_3Q_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_WSTD_3Q();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_WSTD_3Q::Heavy_WSTD_3Q(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sLine_init(&sLine_DNpyMB7R);
  numBytes += sLine_init(&sLine_0blVlLOw);
  numBytes += sLine_init(&sLine_eurLKY2Z);
  numBytes += sLine_init(&sLine_kfwYqmA1);
  numBytes += sLine_init(&sLine_zsBPQua4);
  numBytes += sBiquad_init(&sBiquad_s_mtdP2jhs);
  numBytes += sLine_init(&sLine_1GCVzIqb);
  numBytes += sLine_init(&sLine_ZAkNXRa6);
  numBytes += sLine_init(&sLine_KubcXbeF);
  numBytes += sLine_init(&sLine_H79c9aht);
  numBytes += sBiquad_init(&sBiquad_s_zWyi7Rep);
  numBytes += sLine_init(&sLine_sAgng0iT);
  numBytes += sLine_init(&sLine_ppEL1XyF);
  numBytes += sLine_init(&sLine_WvjXqdXC);
  numBytes += sLine_init(&sLine_rlQZIcjW);
  numBytes += sLine_init(&sLine_JKX0mrxJ);
  numBytes += sBiquad_init(&sBiquad_s_A4sXvaF3);
  numBytes += sLine_init(&sLine_VkDfxStq);
  numBytes += sLine_init(&sLine_fLXXvTSf);
  numBytes += sLine_init(&sLine_s30p1b5a);
  numBytes += sLine_init(&sLine_OS8zYqEm);
  numBytes += sLine_init(&sLine_OU8mXmXc);
  numBytes += sBiquad_init(&sBiquad_s_uEVAijHu);
  numBytes += sLine_init(&sLine_UnsnZzw6);
  numBytes += sLine_init(&sLine_ooxwna9B);
  numBytes += sLine_init(&sLine_h5pqxf1E);
  numBytes += sLine_init(&sLine_OkRJNBLz);
  numBytes += sBiquad_init(&sBiquad_s_Q69k9Q22);
  numBytes += sLine_init(&sLine_rfaGlJGj);
  numBytes += sLine_init(&sLine_jARsFh7u);
  numBytes += sLine_init(&sLine_3qpsIqbD);
  numBytes += sLine_init(&sLine_5EPooetf);
  numBytes += sLine_init(&sLine_v9eBZXEQ);
  numBytes += sBiquad_init(&sBiquad_s_5k4SJeIi);
  numBytes += cVar_init_f(&cVar_CnUPiurH, 0.0f);
  numBytes += cVar_init_f(&cVar_7B9LKYpT, 0.0f);
  numBytes += cVar_init_f(&cVar_uYa5JVze, 0.0f);
  numBytes += cVar_init_f(&cVar_rDjJvoqQ, 0.0f);
  numBytes += cSlice_init(&cSlice_9D3KYD6o, 1, -1);
  numBytes += cVar_init_f(&cVar_qeof1ydL, 1337.0f);
  numBytes += cVar_init_f(&cVar_NHY5vA2w, 0.0f);
  numBytes += cIf_init(&cIf_Gywn4bvy, false);
  numBytes += cIf_init(&cIf_DcxCtvVN, false);
  numBytes += cBinop_init(&cBinop_L4ZuTBoX, 0.0f); // __pow
  numBytes += cIf_init(&cIf_0HVTSR9d, false);
  numBytes += cBinop_init(&cBinop_UtiCVSt6, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_HUZK4b7N, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_NGb4hXnf, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_aGqYbN1t, 0.0f);
  numBytes += cIf_init(&cIf_scyvcLKg, false);
  numBytes += cIf_init(&cIf_JQnARydx, false);
  numBytes += cBinop_init(&cBinop_33ORvtdT, 0.0f); // __pow
  numBytes += cIf_init(&cIf_O0vQxlJC, false);
  numBytes += cBinop_init(&cBinop_xb2HREyo, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_429VX0S2, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_CTonorNQ, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_YlWGGkCd, 0.0f);
  numBytes += cIf_init(&cIf_Fkwq3qsU, false);
  numBytes += cIf_init(&cIf_wDonHQMO, false);
  numBytes += cBinop_init(&cBinop_06meqtRg, 0.0f); // __pow
  numBytes += cIf_init(&cIf_K9gGXpxL, false);
  numBytes += cBinop_init(&cBinop_rNUb4F0N, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_WqOBp7UU, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_6dtAfhRa, -15.0f); // __eq
  numBytes += cIf_init(&cIf_dv7TVm6M, false);
  numBytes += cSlice_init(&cSlice_baZqHfwe, 1, -1);
  numBytes += cVar_init_f(&cVar_bWMlKl5R, 0.0f);
  numBytes += cSlice_init(&cSlice_rKRW1j6M, 1, -1);
  numBytes += cVar_init_f(&cVar_dnF6lza1, 0.0f);
  numBytes += cSlice_init(&cSlice_5BHLo52r, 1, -1);
  numBytes += cVar_init_f(&cVar_gdffGTSn, 0.0f);
  numBytes += cSlice_init(&cSlice_mc4xZPWM, 1, -1);
  numBytes += cVar_init_f(&cVar_tjxfxoLs, 0.313f);
  numBytes += cBinop_init(&cBinop_3NwrJofN, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_gcHZHXRa, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_bSH1VdWI, 0.0f);
  numBytes += cVar_init_f(&cVar_B4Em57Rk, 1337.0f);
  numBytes += cVar_init_f(&cVar_5sNJSBl0, 0.3f);
  numBytes += cBinop_init(&cBinop_J6Ll8HX6, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_9U4AqHbb, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_qUUroXIE, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_zMqNH5AT, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_C5g3ombh, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_aGOwf5oV, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_5WqdVMHn, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_nLZlg4vl, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_rYl7MagN, 0.0f);
  numBytes += cVar_init_f(&cVar_acSufeIf, 1337.0f);
  numBytes += cVar_init_f(&cVar_IUgW0eeh, 0.313f);
  numBytes += cBinop_init(&cBinop_aA2DQkwD, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_3ZdPl3GC, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Sz5wBVg2, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_HcHAkplN, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_1Dn65XNd, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_lo6Qk84Q, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_PCILXoqH, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_iux0nQg6, 0.0f);
  numBytes += cVar_init_f(&cVar_4K8tStRN, 1037.0f);
  numBytes += cVar_init_f(&cVar_AGFJDMKX, 0.4f);
  numBytes += cBinop_init(&cBinop_qfDWNpzl, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Zirgo0x7, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_qhZrxSRH, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_0xhIzsqi, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_fzwl8V64, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_GjuqVLgn, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_zhgZtQ2W, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_HRdlncO2, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Ba4nG8Mq, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_tBrBJwn8, 1, -1);
  numBytes += cVar_init_f(&cVar_owGWMraE, 1337.0f);
  numBytes += cVar_init_f(&cVar_lj9hcjWi, 0.0f);
  numBytes += cIf_init(&cIf_BBt6cpCu, false);
  numBytes += cIf_init(&cIf_43ICnXmj, false);
  numBytes += cBinop_init(&cBinop_qop9WLre, 0.0f); // __pow
  numBytes += cIf_init(&cIf_ElY6YBYD, false);
  numBytes += cBinop_init(&cBinop_Vygu01Ca, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_zsg8kDfk, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_fssSrOhR, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_ODMbZyyY, 0.0f);
  numBytes += cIf_init(&cIf_VGyRIl3E, false);
  numBytes += cIf_init(&cIf_dfu47Wwg, false);
  numBytes += cBinop_init(&cBinop_3iseCdG8, 0.0f); // __pow
  numBytes += cIf_init(&cIf_b1YjRYYv, false);
  numBytes += cBinop_init(&cBinop_hDbOYoAB, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_dJ9QAlTd, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_kvXf3WxR, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_hmFHMTtO, 0.0f);
  numBytes += cIf_init(&cIf_A9nAjc3c, false);
  numBytes += cIf_init(&cIf_7cXSKgNX, false);
  numBytes += cBinop_init(&cBinop_btx2f7Dp, 0.0f); // __pow
  numBytes += cIf_init(&cIf_pEfxLgc1, false);
  numBytes += cBinop_init(&cBinop_yX0U6N96, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_wMLgonj5, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_EL3byBIe, -15.0f); // __eq
  numBytes += cIf_init(&cIf_cLjnPYh6, false);
  numBytes += cSlice_init(&cSlice_4LimNXhK, 1, -1);
  numBytes += cVar_init_f(&cVar_Q0FDSOju, 0.0f);
  numBytes += cSlice_init(&cSlice_IKPdYqo4, 1, -1);
  numBytes += cVar_init_f(&cVar_GJtktxPc, 0.0f);
  numBytes += cSlice_init(&cSlice_D64lpCKY, 1, -1);
  numBytes += cVar_init_f(&cVar_1SFM0sZC, 0.0f);
  numBytes += cSlice_init(&cSlice_cw5NMtnw, 1, -1);
  numBytes += cVar_init_f(&cVar_XBPcIUNx, 0.313f);
  numBytes += cBinop_init(&cBinop_xJwsihzA, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_vtX7hGZY, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_kda49M91, 0.0f);
  numBytes += cVar_init_f(&cVar_lXSyxDqU, 1337.0f);
  numBytes += cVar_init_f(&cVar_QZVNWIlr, 0.3f);
  numBytes += cBinop_init(&cBinop_8edbncJ0, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_xqoUzJoR, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_44EsbUFz, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_iebhPEHl, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_RJuyDA4t, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_z3bVWcbL, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_m8hlJIpo, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_34mHxTmA, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_DTiz1DX2, 0.0f);
  numBytes += cVar_init_f(&cVar_uIHfeTXB, 1337.0f);
  numBytes += cVar_init_f(&cVar_Qw51Tbpw, 0.313f);
  numBytes += cBinop_init(&cBinop_5tW97S2V, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_DQzMzmPt, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_ELDl7tI5, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_2unjB1NW, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_hOcT1dGU, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_KiSzdDyk, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_U0MJ5eQF, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_j9zOLSae, 0.0f);
  numBytes += cVar_init_f(&cVar_SpYQcHH8, 1037.0f);
  numBytes += cVar_init_f(&cVar_gyVuhWRb, 0.4f);
  numBytes += cBinop_init(&cBinop_zwmXu7pz, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_POGMUVFH, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_kKuAyGqr, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_BZKo0L0j, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_23NuwJGU, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_SkghAP3Z, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_YEEastwb, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_dyPFgaSg, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_zZxFxKJJ, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_c3EjjtDJ, 5705.6f);
  numBytes += cVar_init_f(&cVar_nigP5AHU, 313.3f);
  numBytes += cBinop_init(&cBinop_3HP2922f, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_G9L3U8Pw, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_RIUKEGwn, 0.0f); // __div
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_WSTD_3Q::~Heavy_WSTD_3Q() {
  // nothing to free
}

HvTable *Heavy_WSTD_3Q::getTableForHash(hv_uint32_t tableHash) {
  return nullptr;
}

void Heavy_WSTD_3Q::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0xC9CE7B11: { // High
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_XXn8Ns9d_sendMessage);
      break;
    }
    case 0x87744544: { // Low
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_mVHThkoR_sendMessage);
      break;
    }
    case 0xBFDC48B6: { // Mid
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_OzaoSsDR_sendMessage);
      break;
    }
    case 0x59CF21AC: { // Mid_Freq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_TnGy30h2_sendMessage);
      break;
    }
    case 0x24295C10: { // 1010-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_2mVAzorM_sendMessage);
      break;
    }
    case 0x3649681E: { // 1010-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_9fCnH5FS_sendMessage);
      break;
    }
    case 0xD5A8E74D: { // 1010-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_LQ3JNiqX_sendMessage);
      break;
    }
    case 0x60D6F65: { // 1010-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_6zftkQXq_sendMessage);
      break;
    }
    case 0x37E92263: { // 1010-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_G5MJhm5u_sendMessage);
      break;
    }
    case 0x2271964: { // 1069-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ZFMVHSmV_sendMessage);
      break;
    }
    case 0xA61C5543: { // 1069-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_9jfojMPi_sendMessage);
      break;
    }
    case 0x1E13C49D: { // 1069-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_y7Be9h03_sendMessage);
      break;
    }
    case 0xE7448D12: { // 1110-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_9iEpcFni_sendMessage);
      break;
    }
    case 0x5F31ED81: { // 1110-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_dEPcIhhh_sendMessage);
      break;
    }
    case 0xC3520438: { // 1110-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_c0qv7GiA_sendMessage);
      break;
    }
    case 0xB2DA8F9A: { // 1151-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_XdkE8FFW_sendMessage);
      break;
    }
    case 0x668DC2C1: { // 1151-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_3ZR9zThJ_sendMessage);
      break;
    }
    case 0x413B9F30: { // 1151-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_OayPJgmq_sendMessage);
      break;
    }
    case 0x845815A0: { // 1163-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_DhE2lKiy_sendMessage);
      break;
    }
    case 0x5CD8AF91: { // 1163-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_kGJ0rgCI_sendMessage);
      break;
    }
    case 0x188BB7A0: { // 1163-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_l0Xnx72M_sendMessage);
      break;
    }
    case 0xE3BB13E4: { // 1163-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_pNbuAX6V_sendMessage);
      break;
    }
    case 0x3693B415: { // 1163-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Je01cXd2_sendMessage);
      break;
    }
    case 0x1A14721E: { // 1222-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_QidyW0oS_sendMessage);
      break;
    }
    case 0x446DC164: { // 1222-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_LKiZnwmr_sendMessage);
      break;
    }
    case 0x32F45A8B: { // 1222-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_srOGlSqY_sendMessage);
      break;
    }
    case 0x1286072C: { // 1263-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_nyDmQlSM_sendMessage);
      break;
    }
    case 0x7902A17C: { // 1263-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_tRdFdGEZ_sendMessage);
      break;
    }
    case 0x7A57C19C: { // 1263-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_prEH5FJT_sendMessage);
      break;
    }
    case 0x170C9887: { // 1304-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_H1oaWckb_sendMessage);
      break;
    }
    case 0xED0CBA1C: { // 1304-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_bZ3lviQz_sendMessage);
      break;
    }
    case 0xDA3A818C: { // 1304-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_84f1WgBr_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_zfcdI0NM_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_WSTD_3Q::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "High";
        info->hash = 0xC9CE7B11;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 1: {
        info->name = "Low";
        info->hash = 0x87744544;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 2: {
        info->name = "Mid";
        info->hash = 0xBFDC48B6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 3: {
        info->name = "Mid_Freq";
        info->hash = 0x59CF21AC;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 313.3f;
        info->maxVal = 5705.6f;
        info->defaultVal = 1337.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 4;
}



/*
 * Send Function Implementations
 */


void Heavy_WSTD_3Q::cVar_CnUPiurH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_44CAmjBm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_7B9LKYpT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_U8jaekWw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_uYa5JVze_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QC4k6eCM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_rDjJvoqQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_TQeryeUs_sendMessage(_c, 0, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_q7u0sdFU_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_UUiFobBH_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_VoO3bGyn_sendMessage);
}

void Heavy_WSTD_3Q::cSwitchcase_SL5xYQUb_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_9D3KYD6o, 0, m, &cSlice_9D3KYD6o_sendMessage);
      break;
    }
    default: {
      cSwitchcase_OdKNTD3C_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_9D3KYD6o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_pNcGHfAw_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_pNcGHfAw_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_qeof1ydL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_pNcGHfAw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_pNcGHfAw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_LQ3JNiqX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_NHY5vA2w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_2yl9KFuA_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_Gywn4bvy, 0, m, &cIf_Gywn4bvy_sendMessage);
}

void Heavy_WSTD_3Q::cIf_Gywn4bvy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_h9lprIp6_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cIf_DcxCtvVN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_f1a6xjJN_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_TCyDvvRo_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cMsg_FkGq4OgP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_L4ZuTBoX, HV_BINOP_POW, 0, m, &cBinop_L4ZuTBoX_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_L4ZuTBoX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_0HVTSR9d, 0, m, &cIf_0HVTSR9d_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_3QoN9viN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_maanDdyR_sendMessage);
}

void Heavy_WSTD_3Q::cCast_HSXV6QPg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_DcxCtvVN, 0, m, &cIf_DcxCtvVN_sendMessage);
}

void Heavy_WSTD_3Q::cCast_El5zNriS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_vEl4Ddo9_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_vEl4Ddo9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_DcxCtvVN, 1, m, &cIf_DcxCtvVN_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_TCyDvvRo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_3QoN9viN_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_f1a6xjJN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_0HVTSR9d, 0, m, &cIf_0HVTSR9d_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_maanDdyR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_L4ZuTBoX, HV_BINOP_POW, 1, m, &cBinop_L4ZuTBoX_sendMessage);
  cMsg_FkGq4OgP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cIf_0HVTSR9d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_zhgZtQ2W, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cBinop_2yl9KFuA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Gywn4bvy, 1, m, &cIf_Gywn4bvy_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_h9lprIp6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HUZK4b7N, HV_BINOP_GREATER_THAN, 1, m, &cBinop_HUZK4b7N_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_NGb4hXnf, HV_BINOP_EQ, 1, m, &cBinop_NGb4hXnf_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_qWgXcQpb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_UtiCVSt6, HV_BINOP_ADD, 0, m, &cBinop_UtiCVSt6_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_UtiCVSt6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_El5zNriS_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HSXV6QPg_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_HUZK4b7N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_0HVTSR9d, 1, m, &cIf_0HVTSR9d_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_NGb4hXnf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cU4c0UOh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_cU4c0UOh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_zhgZtQ2W, m);
}

void Heavy_WSTD_3Q::cCast_QqsjobJw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UtiCVSt6, HV_BINOP_ADD, 1, m, &cBinop_UtiCVSt6_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_HUZK4b7N, HV_BINOP_GREATER_THAN, 0, m, &cBinop_HUZK4b7N_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_NGb4hXnf, HV_BINOP_EQ, 0, m, &cBinop_NGb4hXnf_sendMessage);
}

void Heavy_WSTD_3Q::cCast_xH9CtVR9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_NHY5vA2w, 0, m, &cVar_NHY5vA2w_sendMessage);
}

void Heavy_WSTD_3Q::cCast_fIiKsHjQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qWgXcQpb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_aGqYbN1t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_xyIewyQ4_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_scyvcLKg, 0, m, &cIf_scyvcLKg_sendMessage);
}

void Heavy_WSTD_3Q::cIf_scyvcLKg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_i0IACnwf_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cIf_JQnARydx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_RhtLbWqu_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_3Hi9zQkv_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cMsg_HUvQcFDe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_33ORvtdT, HV_BINOP_POW, 0, m, &cBinop_33ORvtdT_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_33ORvtdT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_O0vQxlJC, 0, m, &cIf_O0vQxlJC_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_hMNXwlpK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_2pDP8nLB_sendMessage);
}

void Heavy_WSTD_3Q::cCast_9x4wGZYJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_JQnARydx, 0, m, &cIf_JQnARydx_sendMessage);
}

void Heavy_WSTD_3Q::cCast_ZNsjjtcw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_MZVeQRqC_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_MZVeQRqC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_JQnARydx, 1, m, &cIf_JQnARydx_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_3Hi9zQkv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_hMNXwlpK_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_RhtLbWqu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_O0vQxlJC, 0, m, &cIf_O0vQxlJC_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_2pDP8nLB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_33ORvtdT, HV_BINOP_POW, 1, m, &cBinop_33ORvtdT_sendMessage);
  cMsg_HUvQcFDe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cIf_O0vQxlJC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_RkLiKbeo_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_oohMBxSN_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_Nx23oryA_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cBinop_xyIewyQ4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_scyvcLKg, 1, m, &cIf_scyvcLKg_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_i0IACnwf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_429VX0S2, HV_BINOP_GREATER_THAN, 1, m, &cBinop_429VX0S2_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_CTonorNQ, HV_BINOP_EQ, 1, m, &cBinop_CTonorNQ_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_J5Qv2cjT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_xb2HREyo, HV_BINOP_ADD, 0, m, &cBinop_xb2HREyo_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_xb2HREyo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZNsjjtcw_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9x4wGZYJ_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_429VX0S2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_O0vQxlJC, 1, m, &cIf_O0vQxlJC_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_CTonorNQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_a6oqUdI5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_a6oqUdI5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_RkLiKbeo_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_oohMBxSN_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_Nx23oryA_sendMessage);
}

void Heavy_WSTD_3Q::cCast_2magoOlC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_J5Qv2cjT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_akcZn96L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xb2HREyo, HV_BINOP_ADD, 1, m, &cBinop_xb2HREyo_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_429VX0S2, HV_BINOP_GREATER_THAN, 0, m, &cBinop_429VX0S2_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_CTonorNQ, HV_BINOP_EQ, 0, m, &cBinop_CTonorNQ_sendMessage);
}

void Heavy_WSTD_3Q::cCast_29LEr7xW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_aGqYbN1t, 0, m, &cVar_aGqYbN1t_sendMessage);
}

void Heavy_WSTD_3Q::cVar_YlWGGkCd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_seQQ7wLv_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_Fkwq3qsU, 0, m, &cIf_Fkwq3qsU_sendMessage);
}

void Heavy_WSTD_3Q::cIf_Fkwq3qsU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_5KTnMf4z_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cIf_wDonHQMO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_kLps7Q78_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_ghICNUrL_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cMsg_C3Zv16mI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_06meqtRg, HV_BINOP_POW, 0, m, &cBinop_06meqtRg_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_06meqtRg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_K9gGXpxL, 0, m, &cIf_K9gGXpxL_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Qn3kHz8Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_IJxaqVrL_sendMessage);
}

void Heavy_WSTD_3Q::cCast_vipWOhQV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_wDonHQMO, 0, m, &cIf_wDonHQMO_sendMessage);
}

void Heavy_WSTD_3Q::cCast_v5jXiByL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_gZblNPum_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_gZblNPum_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_wDonHQMO, 1, m, &cIf_wDonHQMO_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_ghICNUrL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_Qn3kHz8Y_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_kLps7Q78_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_K9gGXpxL, 0, m, &cIf_K9gGXpxL_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_IJxaqVrL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_06meqtRg, HV_BINOP_POW, 1, m, &cBinop_06meqtRg_sendMessage);
  cMsg_C3Zv16mI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cIf_K9gGXpxL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_Ba4nG8Mq, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cBinop_seQQ7wLv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Fkwq3qsU, 1, m, &cIf_Fkwq3qsU_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_5KTnMf4z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WqOBp7UU, HV_BINOP_GREATER_THAN, 1, m, &cBinop_WqOBp7UU_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_6dtAfhRa, HV_BINOP_EQ, 1, m, &cBinop_6dtAfhRa_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_nRQ3DCsC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_rNUb4F0N, HV_BINOP_ADD, 0, m, &cBinop_rNUb4F0N_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_rNUb4F0N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_v5jXiByL_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vipWOhQV_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_WqOBp7UU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_K9gGXpxL, 1, m, &cIf_K9gGXpxL_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_6dtAfhRa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DqIKrr63_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_DqIKrr63_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_Ba4nG8Mq, m);
}

void Heavy_WSTD_3Q::cCast_m5cyf9X1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rNUb4F0N, HV_BINOP_ADD, 1, m, &cBinop_rNUb4F0N_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_WqOBp7UU, HV_BINOP_GREATER_THAN, 0, m, &cBinop_WqOBp7UU_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_6dtAfhRa, HV_BINOP_EQ, 0, m, &cBinop_6dtAfhRa_sendMessage);
}

void Heavy_WSTD_3Q::cCast_QQqGjEIB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_YlWGGkCd, 0, m, &cVar_YlWGGkCd_sendMessage);
}

void Heavy_WSTD_3Q::cCast_XqL3qy3r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nRQ3DCsC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cIf_dv7TVm6M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_HRdlncO2, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cSwitchcase_JGwP8Hhw_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_baZqHfwe, 0, m, &cSlice_baZqHfwe_sendMessage);
      break;
    }
    default: {
      cSwitchcase_b416RUyi_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_baZqHfwe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_HaQczBLb_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_HaQczBLb_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_bWMlKl5R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_HaQczBLb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_HaQczBLb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_2mVAzorM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSwitchcase_b416RUyi_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_rKRW1j6M, 0, m, &cSlice_rKRW1j6M_sendMessage);
      break;
    }
    default: {
      cSwitchcase_SL5xYQUb_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_rKRW1j6M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_5LvaueHZ_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_5LvaueHZ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_dnF6lza1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_5LvaueHZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_5LvaueHZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_G5MJhm5u_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSwitchcase_OdKNTD3C_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_5BHLo52r, 0, m, &cSlice_5BHLo52r_sendMessage);
      break;
    }
    default: {
      cSwitchcase_FH9IvPkM_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_5BHLo52r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_zr9edSuy_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_zr9edSuy_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_gdffGTSn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_zr9edSuy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_zr9edSuy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_9fCnH5FS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSwitchcase_FH9IvPkM_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_mc4xZPWM, 0, m, &cSlice_mc4xZPWM_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_mc4xZPWM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_I6Og5Tk8_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_I6Og5Tk8_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_tjxfxoLs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_I6Og5Tk8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_I6Og5Tk8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_6zftkQXq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_NZed1OAq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_DNpyMB7R, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_yWG8AYg4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_0blVlLOw, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_gaccSsCH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_eurLKY2Z, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_p2lYCmpJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_kfwYqmA1, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_AJLNyb79_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_zsBPQua4, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_ITVaTz73_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_5pZMyoj4_sendMessage);
}

void Heavy_WSTD_3Q::cSystem_5pZMyoj4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3NwrJofN, HV_BINOP_DIVIDE, 1, m, &cBinop_3NwrJofN_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3QbmwOZa_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_vew9vjBo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_pB9vv2XZ_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_AixHnI9K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_vew9vjBo_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_pB9vv2XZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3NwrJofN, HV_BINOP_DIVIDE, 0, m, &cBinop_3NwrJofN_sendMessage);
}

void Heavy_WSTD_3Q::cCast_3QbmwOZa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_AixHnI9K_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_3NwrJofN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gcHZHXRa, HV_BINOP_MULTIPLY, 1, m, &cBinop_gcHZHXRa_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_gcHZHXRa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_fSORSLJi_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_IusH8J82_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_pOWoRwHm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_NQPqF2VF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cUnop_GxJZwnmb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_uyO1gGnu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_duz3IqTe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_QwXA5BLb_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_QwXA5BLb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gcHZHXRa, HV_BINOP_MULTIPLY, 0, m, &cBinop_gcHZHXRa_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_9ZEaNYLs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_Q8VuxNOF_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Q8VuxNOF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5BQDX7uS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_mGOmJZOm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_bSH1VdWI, 1, m, &cVar_bSH1VdWI_sendMessage);
}

void Heavy_WSTD_3Q::cVar_bSH1VdWI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ErH4a8uA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_1tJbco7O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9U4AqHbb, HV_BINOP_MULTIPLY, 1, m, &cBinop_9U4AqHbb_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_TrKXQrV8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_1tJbco7O_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Ahr547Cm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_94mZhhYF_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_94mZhhYF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qUUroXIE, HV_BINOP_MULTIPLY, 1, m, &cBinop_qUUroXIE_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_GKosPVKE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zMqNH5AT, HV_BINOP_MULTIPLY, 1, m, &cBinop_zMqNH5AT_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_wccudksg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_GKosPVKE_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_tafOSmxl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_C5g3ombh, HV_BINOP_MULTIPLY, 1, m, &cBinop_C5g3ombh_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_buHuBSZ1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_WXkNDiWP_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_WXkNDiWP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_aGOwf5oV, HV_BINOP_MULTIPLY, 1, m, &cBinop_aGOwf5oV_sendMessage);
}

void Heavy_WSTD_3Q::cVar_B4Em57Rk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_x6tc82Lr_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_duz3IqTe_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_XeaIsupE_sendMessage);
}

void Heavy_WSTD_3Q::cVar_5sNJSBl0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_9ZEaNYLs_sendMessage);
}

void Heavy_WSTD_3Q::cCast_IusH8J82_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_GxJZwnmb_sendMessage);
}

void Heavy_WSTD_3Q::cCast_fSORSLJi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_pOWoRwHm_sendMessage);
}

void Heavy_WSTD_3Q::cSend_NQPqF2VF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_y7Be9h03_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_uyO1gGnu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_9jfojMPi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_r75LPVJo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ZFMVHSmV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_5BQDX7uS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_tpES6Bds_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_tpES6Bds_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_J6Ll8HX6, HV_BINOP_MULTIPLY, 1, m, &cBinop_J6Ll8HX6_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_J6Ll8HX6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_qVw6SQOM_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_qVw6SQOM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_r75LPVJo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_ErH4a8uA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_Rm2bXagC_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Rm2bXagC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MeD2qWIV_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_JKvR5s0L_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FsWkg1Fb_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_faLi6Ckf_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_82uJ9yzt_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_cLLZE3s4_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_9U4AqHbb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NZed1OAq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_qUUroXIE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_yWG8AYg4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_zMqNH5AT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gaccSsCH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_C5g3ombh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_p2lYCmpJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_aGOwf5oV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_AJLNyb79_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_l7oxOoJO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_B4Em57Rk, 0, m, &cVar_B4Em57Rk_sendMessage);
}

void Heavy_WSTD_3Q::cCast_GFXYCX1J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_5sNJSBl0, 1, m, &cVar_5sNJSBl0_sendMessage);
}

void Heavy_WSTD_3Q::cCast_faLi6Ckf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zMqNH5AT, HV_BINOP_MULTIPLY, 0, m, &cBinop_zMqNH5AT_sendMessage);
}

void Heavy_WSTD_3Q::cCast_MeD2qWIV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_3Q::cCast_cLLZE3s4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9U4AqHbb, HV_BINOP_MULTIPLY, 0, m, &cBinop_9U4AqHbb_sendMessage);
}

void Heavy_WSTD_3Q::cCast_FsWkg1Fb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_C5g3ombh, HV_BINOP_MULTIPLY, 0, m, &cBinop_C5g3ombh_sendMessage);
}

void Heavy_WSTD_3Q::cCast_82uJ9yzt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qUUroXIE, HV_BINOP_MULTIPLY, 0, m, &cBinop_qUUroXIE_sendMessage);
}

void Heavy_WSTD_3Q::cCast_JKvR5s0L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_aGOwf5oV, HV_BINOP_MULTIPLY, 0, m, &cBinop_aGOwf5oV_sendMessage);
}

void Heavy_WSTD_3Q::cCast_x6tc82Lr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_5sNJSBl0, 0, m, &cVar_5sNJSBl0_sendMessage);
}

void Heavy_WSTD_3Q::cCast_XeaIsupE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_bSH1VdWI, 0, m, &cVar_bSH1VdWI_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_1Y4GSXfK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_1GCVzIqb, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_7eRRrBKJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ZAkNXRa6, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_tNOF8his_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_KubcXbeF, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_fREyTDl5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_H79c9aht, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_S5V7eJsV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_0g5FCZQt_sendMessage);
}

void Heavy_WSTD_3Q::cSystem_0g5FCZQt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5WqdVMHn, HV_BINOP_DIVIDE, 1, m, &cBinop_5WqdVMHn_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9NgQEUZG_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_RrkbdpVz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_1qmDFuvw_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_88fMV8u4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_RrkbdpVz_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_1qmDFuvw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5WqdVMHn, HV_BINOP_DIVIDE, 0, m, &cBinop_5WqdVMHn_sendMessage);
}

void Heavy_WSTD_3Q::cCast_9NgQEUZG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_88fMV8u4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_5WqdVMHn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nLZlg4vl, HV_BINOP_MULTIPLY, 1, m, &cBinop_nLZlg4vl_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_nLZlg4vl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_mnkQ5WUv_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Jpz3q4wE_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_ZeOVs8K6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_BUp7zup4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cUnop_Dq6a6lz0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_0sQshBCW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_JWEB16i7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_dRris2PA_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_dRris2PA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nLZlg4vl, HV_BINOP_MULTIPLY, 0, m, &cBinop_nLZlg4vl_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_f7DNprH0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_wg157FCB_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_wg157FCB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_VVZHqck5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_wgizh9S9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Sz5wBVg2, HV_BINOP_MULTIPLY, 1, m, &cBinop_Sz5wBVg2_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_t6QGABcM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_rYl7MagN, 1, m, &cVar_rYl7MagN_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_zaGSu8UV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HcHAkplN, HV_BINOP_MULTIPLY, 1, m, &cBinop_HcHAkplN_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_P3NziZmr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_UydfAEAy_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_UydfAEAy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1Dn65XNd, HV_BINOP_MULTIPLY, 1, m, &cBinop_1Dn65XNd_sendMessage);
}

void Heavy_WSTD_3Q::cVar_rYl7MagN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RKjJ9EfU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_acSufeIf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YXOKKO9Y_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_JWEB16i7_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_uutKNvod_sendMessage);
}

void Heavy_WSTD_3Q::cVar_IUgW0eeh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_f7DNprH0_sendMessage);
}

void Heavy_WSTD_3Q::cCast_mnkQ5WUv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_ZeOVs8K6_sendMessage);
}

void Heavy_WSTD_3Q::cCast_Jpz3q4wE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_Dq6a6lz0_sendMessage);
}

void Heavy_WSTD_3Q::cSend_BUp7zup4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_c0qv7GiA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_0sQshBCW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_dEPcIhhh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_pwLpOukF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_9iEpcFni_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_VVZHqck5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_foyrT398_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_foyrT398_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_aA2DQkwD, HV_BINOP_MULTIPLY, 1, m, &cBinop_aA2DQkwD_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_aA2DQkwD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_70N1Q6yV_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_70N1Q6yV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_pwLpOukF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_RKjJ9EfU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_EXGynVtk_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_EXGynVtk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9uFdbuPc_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_XjVJN4cf_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zrziVqNi_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zKJJuWfA_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_3ZdPl3GC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1Y4GSXfK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_Sz5wBVg2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7eRRrBKJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_HcHAkplN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tNOF8his_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_1Dn65XNd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fREyTDl5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_FijjeMkQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_IUgW0eeh, 1, m, &cVar_IUgW0eeh_sendMessage);
}

void Heavy_WSTD_3Q::cCast_mlTaHp01_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_acSufeIf, 0, m, &cVar_acSufeIf_sendMessage);
}

void Heavy_WSTD_3Q::cCast_uutKNvod_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_rYl7MagN, 0, m, &cVar_rYl7MagN_sendMessage);
}

void Heavy_WSTD_3Q::cCast_YXOKKO9Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_IUgW0eeh, 0, m, &cVar_IUgW0eeh_sendMessage);
}

void Heavy_WSTD_3Q::cCast_XjVJN4cf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HcHAkplN, HV_BINOP_MULTIPLY, 0, m, &cBinop_HcHAkplN_sendMessage);
}

void Heavy_WSTD_3Q::cCast_9uFdbuPc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1Dn65XNd, HV_BINOP_MULTIPLY, 0, m, &cBinop_1Dn65XNd_sendMessage);
}

void Heavy_WSTD_3Q::cCast_zrziVqNi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Sz5wBVg2, HV_BINOP_MULTIPLY, 0, m, &cBinop_Sz5wBVg2_sendMessage);
}

void Heavy_WSTD_3Q::cCast_zKJJuWfA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3ZdPl3GC, HV_BINOP_MULTIPLY, 0, m, &cBinop_3ZdPl3GC_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_lF2fyyT2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_sAgng0iT, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_KHidMzN9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ppEL1XyF, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_GDSyBG9m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_WvjXqdXC, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_41yn09gS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_rlQZIcjW, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_BgzJB8on_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_JKX0mrxJ, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_PCBZPRMn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_3ulpPOD7_sendMessage);
}

void Heavy_WSTD_3Q::cSystem_3ulpPOD7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lo6Qk84Q, HV_BINOP_DIVIDE, 1, m, &cBinop_lo6Qk84Q_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_89bMmLR7_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_FTWsRvad_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_GcPnbZtN_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_OJrJc3qu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_FTWsRvad_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_GcPnbZtN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lo6Qk84Q, HV_BINOP_DIVIDE, 0, m, &cBinop_lo6Qk84Q_sendMessage);
}

void Heavy_WSTD_3Q::cCast_89bMmLR7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_OJrJc3qu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_lo6Qk84Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PCILXoqH, HV_BINOP_MULTIPLY, 1, m, &cBinop_PCILXoqH_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_PCILXoqH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_VDqBe5fa_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MS8HufBS_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_lnznJId6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_vxWHG7In_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cUnop_w0umilGR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_x1DZgccb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_mSg2Lytt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_1J9gAW73_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_1J9gAW73_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PCILXoqH, HV_BINOP_MULTIPLY, 0, m, &cBinop_PCILXoqH_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_gm2h8HbW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_dEZbufKW_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_dEZbufKW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PCW8qGSV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_J2oVpKSa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Zirgo0x7, HV_BINOP_MULTIPLY, 1, m, &cBinop_Zirgo0x7_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_Z6PZwTyv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_3XApj9bG_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_3XApj9bG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_J2oVpKSa_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_yk0VrdPe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_0N1sQ7pl_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_0N1sQ7pl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qhZrxSRH, HV_BINOP_MULTIPLY, 1, m, &cBinop_qhZrxSRH_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_epD7AgDX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0xhIzsqi, HV_BINOP_MULTIPLY, 1, m, &cBinop_0xhIzsqi_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_4O3KTQoA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_73JSeZ8S_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_73JSeZ8S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_epD7AgDX_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_DC9KjZlK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_iux0nQg6, 1, m, &cVar_iux0nQg6_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_GHYdZM0m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fzwl8V64, HV_BINOP_MULTIPLY, 1, m, &cBinop_fzwl8V64_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_XyRDfCkL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_mIdTqhid_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_mIdTqhid_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GjuqVLgn, HV_BINOP_MULTIPLY, 1, m, &cBinop_GjuqVLgn_sendMessage);
}

void Heavy_WSTD_3Q::cVar_iux0nQg6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nXYLuYjj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_4K8tStRN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_sNaQDiN8_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_mSg2Lytt_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2yio7oM0_sendMessage);
}

void Heavy_WSTD_3Q::cVar_AGFJDMKX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_gm2h8HbW_sendMessage);
}

void Heavy_WSTD_3Q::cCast_MS8HufBS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_w0umilGR_sendMessage);
}

void Heavy_WSTD_3Q::cCast_VDqBe5fa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_lnznJId6_sendMessage);
}

void Heavy_WSTD_3Q::cSend_vxWHG7In_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_OayPJgmq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_x1DZgccb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_3ZR9zThJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_ygWaksPs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_XdkE8FFW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_PCW8qGSV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_a0Hn9lko_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_a0Hn9lko_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qfDWNpzl, HV_BINOP_MULTIPLY, 1, m, &cBinop_qfDWNpzl_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_qfDWNpzl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_JvToYFvd_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_JvToYFvd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ygWaksPs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_nXYLuYjj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_cdKKU0Lk_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_cdKKU0Lk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dPmx8lzY_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hqdqiDw3_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_j7IPUt58_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xGMGKiim_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_f9reZ5kz_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Wb0y1Ful_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Zirgo0x7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_lF2fyyT2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_qhZrxSRH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KHidMzN9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_0xhIzsqi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GDSyBG9m_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_fzwl8V64_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_41yn09gS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_GjuqVLgn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BgzJB8on_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_9hHFVzzP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_AGFJDMKX, 1, m, &cVar_AGFJDMKX_sendMessage);
}

void Heavy_WSTD_3Q::cCast_Hxnkdn0X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_4K8tStRN, 0, m, &cVar_4K8tStRN_sendMessage);
}

void Heavy_WSTD_3Q::cCast_xGMGKiim_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0xhIzsqi, HV_BINOP_MULTIPLY, 0, m, &cBinop_0xhIzsqi_sendMessage);
}

void Heavy_WSTD_3Q::cCast_dPmx8lzY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_3Q::cCast_Wb0y1Ful_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Zirgo0x7, HV_BINOP_MULTIPLY, 0, m, &cBinop_Zirgo0x7_sendMessage);
}

void Heavy_WSTD_3Q::cCast_j7IPUt58_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fzwl8V64, HV_BINOP_MULTIPLY, 0, m, &cBinop_fzwl8V64_sendMessage);
}

void Heavy_WSTD_3Q::cCast_f9reZ5kz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qhZrxSRH, HV_BINOP_MULTIPLY, 0, m, &cBinop_qhZrxSRH_sendMessage);
}

void Heavy_WSTD_3Q::cCast_hqdqiDw3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GjuqVLgn, HV_BINOP_MULTIPLY, 0, m, &cBinop_GjuqVLgn_sendMessage);
}

void Heavy_WSTD_3Q::cCast_sNaQDiN8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_AGFJDMKX, 0, m, &cVar_AGFJDMKX_sendMessage);
}

void Heavy_WSTD_3Q::cCast_2yio7oM0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_iux0nQg6, 0, m, &cVar_iux0nQg6_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_RkLiKbeo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_dv7TVm6M, 1, m, &cIf_dv7TVm6M_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_17WldaTZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_HRdlncO2, m);
}

void Heavy_WSTD_3Q::cBinop_oohMBxSN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_17WldaTZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_Nx23oryA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_dv7TVm6M, 0, m, &cIf_dv7TVm6M_sendMessage);
}

void Heavy_WSTD_3Q::cSwitchcase_FkEHQatR_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_tBrBJwn8, 0, m, &cSlice_tBrBJwn8_sendMessage);
      break;
    }
    default: {
      cSwitchcase_JnrRAmp3_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_tBrBJwn8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_RA6ukz5o_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_RA6ukz5o_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_owGWMraE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_RA6ukz5o_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_RA6ukz5o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_l0Xnx72M_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_lj9hcjWi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_CFSXQ7PJ_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_BBt6cpCu, 0, m, &cIf_BBt6cpCu_sendMessage);
}

void Heavy_WSTD_3Q::cIf_BBt6cpCu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_0mxAkIQd_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cIf_43ICnXmj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_3YNzuGqu_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_86tqlbPB_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cMsg_FuNMez8l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_qop9WLre, HV_BINOP_POW, 0, m, &cBinop_qop9WLre_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_qop9WLre_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ElY6YBYD, 0, m, &cIf_ElY6YBYD_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Hqvxs4qB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_Wq7vU1Xx_sendMessage);
}

void Heavy_WSTD_3Q::cCast_ott5nHZC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_43ICnXmj, 0, m, &cIf_43ICnXmj_sendMessage);
}

void Heavy_WSTD_3Q::cCast_AtM3C9qi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_BjAAngMJ_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_BjAAngMJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_43ICnXmj, 1, m, &cIf_43ICnXmj_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_86tqlbPB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_Hqvxs4qB_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_3YNzuGqu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_ElY6YBYD, 0, m, &cIf_ElY6YBYD_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Wq7vU1Xx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qop9WLre, HV_BINOP_POW, 1, m, &cBinop_qop9WLre_sendMessage);
  cMsg_FuNMez8l_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cIf_ElY6YBYD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_YEEastwb, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cBinop_CFSXQ7PJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_BBt6cpCu, 1, m, &cIf_BBt6cpCu_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_0mxAkIQd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zsg8kDfk, HV_BINOP_GREATER_THAN, 1, m, &cBinop_zsg8kDfk_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_fssSrOhR, HV_BINOP_EQ, 1, m, &cBinop_fssSrOhR_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_6cTUCYUY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Vygu01Ca, HV_BINOP_ADD, 0, m, &cBinop_Vygu01Ca_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Vygu01Ca_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_AtM3C9qi_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ott5nHZC_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_zsg8kDfk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ElY6YBYD, 1, m, &cIf_ElY6YBYD_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_fssSrOhR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dP05W6hD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_dP05W6hD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_YEEastwb, m);
}

void Heavy_WSTD_3Q::cCast_ZDlx9afM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6cTUCYUY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_v5r3gwkt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Vygu01Ca, HV_BINOP_ADD, 1, m, &cBinop_Vygu01Ca_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_zsg8kDfk, HV_BINOP_GREATER_THAN, 0, m, &cBinop_zsg8kDfk_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_fssSrOhR, HV_BINOP_EQ, 0, m, &cBinop_fssSrOhR_sendMessage);
}

void Heavy_WSTD_3Q::cCast_mOtr4obB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_lj9hcjWi, 0, m, &cVar_lj9hcjWi_sendMessage);
}

void Heavy_WSTD_3Q::cVar_ODMbZyyY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_fVcdWUzm_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_VGyRIl3E, 0, m, &cIf_VGyRIl3E_sendMessage);
}

void Heavy_WSTD_3Q::cIf_VGyRIl3E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_7ShjMCHX_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cIf_dfu47Wwg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_5RGahe4Q_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_ZKPpd4hA_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cMsg_jySRJ2np_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_3iseCdG8, HV_BINOP_POW, 0, m, &cBinop_3iseCdG8_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_3iseCdG8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_b1YjRYYv, 0, m, &cIf_b1YjRYYv_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_2WuiS0NN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_1KA9y7ff_sendMessage);
}

void Heavy_WSTD_3Q::cCast_8GOzG2Zd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_QNH4Htj8_sendMessage);
}

void Heavy_WSTD_3Q::cCast_RZRyDddJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_dfu47Wwg, 0, m, &cIf_dfu47Wwg_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_QNH4Htj8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_dfu47Wwg, 1, m, &cIf_dfu47Wwg_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_ZKPpd4hA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_2WuiS0NN_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_5RGahe4Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_b1YjRYYv, 0, m, &cIf_b1YjRYYv_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_1KA9y7ff_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3iseCdG8, HV_BINOP_POW, 1, m, &cBinop_3iseCdG8_sendMessage);
  cMsg_jySRJ2np_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cIf_b1YjRYYv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_GjY8PWFJ_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_tCZRcDbM_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_OyC66tCa_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cBinop_fVcdWUzm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_VGyRIl3E, 1, m, &cIf_VGyRIl3E_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_7ShjMCHX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dJ9QAlTd, HV_BINOP_GREATER_THAN, 1, m, &cBinop_dJ9QAlTd_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_kvXf3WxR, HV_BINOP_EQ, 1, m, &cBinop_kvXf3WxR_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_clWOlzNa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_hDbOYoAB, HV_BINOP_ADD, 0, m, &cBinop_hDbOYoAB_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_hDbOYoAB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8GOzG2Zd_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_RZRyDddJ_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_dJ9QAlTd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_b1YjRYYv, 1, m, &cIf_b1YjRYYv_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_kvXf3WxR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MJVerY2J_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_MJVerY2J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_GjY8PWFJ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_tCZRcDbM_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_OyC66tCa_sendMessage);
}

void Heavy_WSTD_3Q::cCast_LkWH505O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ODMbZyyY, 0, m, &cVar_ODMbZyyY_sendMessage);
}

void Heavy_WSTD_3Q::cCast_V7MtnjS8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_clWOlzNa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_yy1Yd4tg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hDbOYoAB, HV_BINOP_ADD, 1, m, &cBinop_hDbOYoAB_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_dJ9QAlTd, HV_BINOP_GREATER_THAN, 0, m, &cBinop_dJ9QAlTd_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_kvXf3WxR, HV_BINOP_EQ, 0, m, &cBinop_kvXf3WxR_sendMessage);
}

void Heavy_WSTD_3Q::cVar_hmFHMTtO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_NDOrtDGm_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_A9nAjc3c, 0, m, &cIf_A9nAjc3c_sendMessage);
}

void Heavy_WSTD_3Q::cIf_A9nAjc3c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_9QVOwhUO_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cIf_7cXSKgNX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_cG2aGccQ_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_iXlRpbjb_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cMsg_1GjRpIRV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_btx2f7Dp, HV_BINOP_POW, 0, m, &cBinop_btx2f7Dp_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_btx2f7Dp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_pEfxLgc1, 0, m, &cIf_pEfxLgc1_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_QMIjGrig_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_0hXnnlbD_sendMessage);
}

void Heavy_WSTD_3Q::cCast_ZJfE9HjZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_7cXSKgNX, 0, m, &cIf_7cXSKgNX_sendMessage);
}

void Heavy_WSTD_3Q::cCast_9r9xD7lK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_a024Xue0_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_a024Xue0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_7cXSKgNX, 1, m, &cIf_7cXSKgNX_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_iXlRpbjb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_QMIjGrig_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_cG2aGccQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_pEfxLgc1, 0, m, &cIf_pEfxLgc1_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_0hXnnlbD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_btx2f7Dp, HV_BINOP_POW, 1, m, &cBinop_btx2f7Dp_sendMessage);
  cMsg_1GjRpIRV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cIf_pEfxLgc1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_zZxFxKJJ, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cBinop_NDOrtDGm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_A9nAjc3c, 1, m, &cIf_A9nAjc3c_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_9QVOwhUO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wMLgonj5, HV_BINOP_GREATER_THAN, 1, m, &cBinop_wMLgonj5_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_EL3byBIe, HV_BINOP_EQ, 1, m, &cBinop_EL3byBIe_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_LSa1f4Vy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_yX0U6N96, HV_BINOP_ADD, 0, m, &cBinop_yX0U6N96_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_yX0U6N96_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9r9xD7lK_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZJfE9HjZ_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_wMLgonj5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_pEfxLgc1, 1, m, &cIf_pEfxLgc1_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_EL3byBIe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7P3spPeg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_7P3spPeg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_zZxFxKJJ, m);
}

void Heavy_WSTD_3Q::cCast_MoO7K8Qm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yX0U6N96, HV_BINOP_ADD, 1, m, &cBinop_yX0U6N96_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_wMLgonj5, HV_BINOP_GREATER_THAN, 0, m, &cBinop_wMLgonj5_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_EL3byBIe, HV_BINOP_EQ, 0, m, &cBinop_EL3byBIe_sendMessage);
}

void Heavy_WSTD_3Q::cCast_Jnj0ULav_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_hmFHMTtO, 0, m, &cVar_hmFHMTtO_sendMessage);
}

void Heavy_WSTD_3Q::cCast_vkFnRpPB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LSa1f4Vy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cIf_cLjnPYh6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_dyPFgaSg, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cSwitchcase_QknMIXvM_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_4LimNXhK, 0, m, &cSlice_4LimNXhK_sendMessage);
      break;
    }
    default: {
      cSwitchcase_LVhTGa78_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_4LimNXhK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_S0YOTzMa_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_S0YOTzMa_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_Q0FDSOju_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_S0YOTzMa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_S0YOTzMa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_DhE2lKiy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSwitchcase_LVhTGa78_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_IKPdYqo4, 0, m, &cSlice_IKPdYqo4_sendMessage);
      break;
    }
    default: {
      cSwitchcase_FkEHQatR_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_IKPdYqo4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_iT0dNm86_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_iT0dNm86_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_GJtktxPc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_iT0dNm86_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_iT0dNm86_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Je01cXd2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSwitchcase_JnrRAmp3_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_D64lpCKY, 0, m, &cSlice_D64lpCKY_sendMessage);
      break;
    }
    default: {
      cSwitchcase_svd2p6Gy_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_D64lpCKY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_5hZD7PtI_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_5hZD7PtI_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_1SFM0sZC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_5hZD7PtI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_5hZD7PtI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_kGJ0rgCI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSwitchcase_svd2p6Gy_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_cw5NMtnw, 0, m, &cSlice_cw5NMtnw_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_cw5NMtnw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_mSK0Hn5g_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_mSK0Hn5g_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_XBPcIUNx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_mSK0Hn5g_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_mSK0Hn5g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_pNbuAX6V_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_u7XNeDQ0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_VkDfxStq, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_zsx8sGlx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_fLXXvTSf, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_JIct0QPJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_s30p1b5a, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_uouL02zT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_OS8zYqEm, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_Uak3kMIo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_OU8mXmXc, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_rOsRYCow_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_i1FaUvhO_sendMessage);
}

void Heavy_WSTD_3Q::cSystem_i1FaUvhO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xJwsihzA, HV_BINOP_DIVIDE, 1, m, &cBinop_xJwsihzA_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OOtsdaCf_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_gMMEOapI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_Z6MNd8gb_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_oQoRF3du_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_gMMEOapI_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Z6MNd8gb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xJwsihzA, HV_BINOP_DIVIDE, 0, m, &cBinop_xJwsihzA_sendMessage);
}

void Heavy_WSTD_3Q::cCast_OOtsdaCf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_oQoRF3du_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_xJwsihzA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vtX7hGZY, HV_BINOP_MULTIPLY, 1, m, &cBinop_vtX7hGZY_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_vtX7hGZY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_SvE7o8iq_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_WIQME0Fq_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_6DKYbPMq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_OdgZoh9d_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cUnop_1dFXgXb1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ZsErlxUg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_GatTj9oM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_Iua7CRVn_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Iua7CRVn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vtX7hGZY, HV_BINOP_MULTIPLY, 0, m, &cBinop_vtX7hGZY_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_3ULwT170_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_JIOQ1fdw_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_JIOQ1fdw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fGtX2Qv1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_YbB86tSP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_kda49M91, 1, m, &cVar_kda49M91_sendMessage);
}

void Heavy_WSTD_3Q::cVar_kda49M91_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ErnM63PF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_MIAzZCnM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xqoUzJoR, HV_BINOP_MULTIPLY, 1, m, &cBinop_xqoUzJoR_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_eQewMhjt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_MIAzZCnM_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_8T4aSlif_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_kGhAM5fd_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_kGhAM5fd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_44EsbUFz, HV_BINOP_MULTIPLY, 1, m, &cBinop_44EsbUFz_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_cM91tRXn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_iebhPEHl, HV_BINOP_MULTIPLY, 1, m, &cBinop_iebhPEHl_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_qBbkcvzu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_cM91tRXn_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_5QtkMUYs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_RJuyDA4t, HV_BINOP_MULTIPLY, 1, m, &cBinop_RJuyDA4t_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_PZj9eQN3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_yOk3m1lY_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_yOk3m1lY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_z3bVWcbL, HV_BINOP_MULTIPLY, 1, m, &cBinop_z3bVWcbL_sendMessage);
}

void Heavy_WSTD_3Q::cVar_lXSyxDqU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_krsEgior_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_GatTj9oM_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QvY16KWk_sendMessage);
}

void Heavy_WSTD_3Q::cVar_QZVNWIlr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_3ULwT170_sendMessage);
}

void Heavy_WSTD_3Q::cCast_SvE7o8iq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_6DKYbPMq_sendMessage);
}

void Heavy_WSTD_3Q::cCast_WIQME0Fq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_1dFXgXb1_sendMessage);
}

void Heavy_WSTD_3Q::cSend_OdgZoh9d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_srOGlSqY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_ZsErlxUg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_LKiZnwmr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_vDyy1RzH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_QidyW0oS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_fGtX2Qv1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_lg4eq9TK_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_lg4eq9TK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8edbncJ0, HV_BINOP_MULTIPLY, 1, m, &cBinop_8edbncJ0_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_8edbncJ0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_RH6zaZdk_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_RH6zaZdk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_vDyy1RzH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_ErnM63PF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_H35oSiFX_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_H35oSiFX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_382C7s5X_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TAMXoYcT_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Kkr8gZ2a_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_JOrEQCty_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_71IzZ19I_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_O206oTTy_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_xqoUzJoR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_u7XNeDQ0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_44EsbUFz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zsx8sGlx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_iebhPEHl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JIct0QPJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_RJuyDA4t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_uouL02zT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_z3bVWcbL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Uak3kMIo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_i16O5EkJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_lXSyxDqU, 0, m, &cVar_lXSyxDqU_sendMessage);
}

void Heavy_WSTD_3Q::cCast_n51plNcQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_QZVNWIlr, 1, m, &cVar_QZVNWIlr_sendMessage);
}

void Heavy_WSTD_3Q::cCast_382C7s5X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_3Q::cCast_O206oTTy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xqoUzJoR, HV_BINOP_MULTIPLY, 0, m, &cBinop_xqoUzJoR_sendMessage);
}

void Heavy_WSTD_3Q::cCast_Kkr8gZ2a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_RJuyDA4t, HV_BINOP_MULTIPLY, 0, m, &cBinop_RJuyDA4t_sendMessage);
}

void Heavy_WSTD_3Q::cCast_71IzZ19I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_44EsbUFz, HV_BINOP_MULTIPLY, 0, m, &cBinop_44EsbUFz_sendMessage);
}

void Heavy_WSTD_3Q::cCast_TAMXoYcT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_z3bVWcbL, HV_BINOP_MULTIPLY, 0, m, &cBinop_z3bVWcbL_sendMessage);
}

void Heavy_WSTD_3Q::cCast_JOrEQCty_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_iebhPEHl, HV_BINOP_MULTIPLY, 0, m, &cBinop_iebhPEHl_sendMessage);
}

void Heavy_WSTD_3Q::cCast_QvY16KWk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_kda49M91, 0, m, &cVar_kda49M91_sendMessage);
}

void Heavy_WSTD_3Q::cCast_krsEgior_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_QZVNWIlr, 0, m, &cVar_QZVNWIlr_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_NIJ6mho9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_UnsnZzw6, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_laKv2t75_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ooxwna9B, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_5Q8QBoUM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_h5pqxf1E, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_l7z33Baq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_OkRJNBLz, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_9Yw6VBnp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_HrH8NgCd_sendMessage);
}

void Heavy_WSTD_3Q::cSystem_HrH8NgCd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_m8hlJIpo, HV_BINOP_DIVIDE, 1, m, &cBinop_m8hlJIpo_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2Ca2K792_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_IfjVPHqC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_qtDtc5bh_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_yQsfSva8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_IfjVPHqC_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_qtDtc5bh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_m8hlJIpo, HV_BINOP_DIVIDE, 0, m, &cBinop_m8hlJIpo_sendMessage);
}

void Heavy_WSTD_3Q::cCast_2Ca2K792_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_yQsfSva8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_m8hlJIpo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_34mHxTmA, HV_BINOP_MULTIPLY, 1, m, &cBinop_34mHxTmA_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_34mHxTmA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_voE8Zjty_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2KiVvKbb_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_ivDOrNn0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_z02mbZWP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cUnop_O6A9Zw2s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ajj07Ox4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_3pdu6ybd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_3CxEwAQ0_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_3CxEwAQ0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_34mHxTmA, HV_BINOP_MULTIPLY, 0, m, &cBinop_34mHxTmA_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_BaBijiRp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_U3TEPfMy_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_U3TEPfMy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_IlIZnaUT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_2xmsbxWb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ELDl7tI5, HV_BINOP_MULTIPLY, 1, m, &cBinop_ELDl7tI5_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_3Qe3vQRY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_DTiz1DX2, 1, m, &cVar_DTiz1DX2_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_BSNYzVQF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2unjB1NW, HV_BINOP_MULTIPLY, 1, m, &cBinop_2unjB1NW_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_ka4iLuZm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_0GGDv7Lw_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_0GGDv7Lw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hOcT1dGU, HV_BINOP_MULTIPLY, 1, m, &cBinop_hOcT1dGU_sendMessage);
}

void Heavy_WSTD_3Q::cVar_DTiz1DX2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SLA2X8lb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_uIHfeTXB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5xh2Foku_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_3pdu6ybd_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_aau4bAb7_sendMessage);
}

void Heavy_WSTD_3Q::cVar_Qw51Tbpw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_BaBijiRp_sendMessage);
}

void Heavy_WSTD_3Q::cCast_voE8Zjty_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_ivDOrNn0_sendMessage);
}

void Heavy_WSTD_3Q::cCast_2KiVvKbb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_O6A9Zw2s_sendMessage);
}

void Heavy_WSTD_3Q::cSend_z02mbZWP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_prEH5FJT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_ajj07Ox4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_tRdFdGEZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_AmAHjHrP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_nyDmQlSM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_IlIZnaUT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_iQraZGGp_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_iQraZGGp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5tW97S2V, HV_BINOP_MULTIPLY, 1, m, &cBinop_5tW97S2V_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_5tW97S2V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_CkxQIwqd_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_CkxQIwqd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_AmAHjHrP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_SLA2X8lb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_hakB3ENN_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_hakB3ENN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_g5553UVR_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Hmv7JNs8_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_yFi1GnaQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_yFD55MMK_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_DQzMzmPt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NIJ6mho9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_ELDl7tI5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_laKv2t75_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_2unjB1NW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5Q8QBoUM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_hOcT1dGU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_l7z33Baq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_1pd26Sku_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Qw51Tbpw, 1, m, &cVar_Qw51Tbpw_sendMessage);
}

void Heavy_WSTD_3Q::cCast_KGLsCIlo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_uIHfeTXB, 0, m, &cVar_uIHfeTXB_sendMessage);
}

void Heavy_WSTD_3Q::cCast_aau4bAb7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_DTiz1DX2, 0, m, &cVar_DTiz1DX2_sendMessage);
}

void Heavy_WSTD_3Q::cCast_5xh2Foku_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Qw51Tbpw, 0, m, &cVar_Qw51Tbpw_sendMessage);
}

void Heavy_WSTD_3Q::cCast_yFi1GnaQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ELDl7tI5, HV_BINOP_MULTIPLY, 0, m, &cBinop_ELDl7tI5_sendMessage);
}

void Heavy_WSTD_3Q::cCast_Hmv7JNs8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2unjB1NW, HV_BINOP_MULTIPLY, 0, m, &cBinop_2unjB1NW_sendMessage);
}

void Heavy_WSTD_3Q::cCast_yFD55MMK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DQzMzmPt, HV_BINOP_MULTIPLY, 0, m, &cBinop_DQzMzmPt_sendMessage);
}

void Heavy_WSTD_3Q::cCast_g5553UVR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hOcT1dGU, HV_BINOP_MULTIPLY, 0, m, &cBinop_hOcT1dGU_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_LBIzB4kt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_rfaGlJGj, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_c9e0ptyd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_jARsFh7u, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_XHpz13iz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_3qpsIqbD, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_3E7mWLtU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_5EPooetf, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_I3ZCCm81_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_v9eBZXEQ, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_soBsNfgR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_9e18XKtr_sendMessage);
}

void Heavy_WSTD_3Q::cSystem_9e18XKtr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KiSzdDyk, HV_BINOP_DIVIDE, 1, m, &cBinop_KiSzdDyk_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JHRznFob_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_2rMbr5N7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_hfywvLwf_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_cZIfeP4o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_2rMbr5N7_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_hfywvLwf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KiSzdDyk, HV_BINOP_DIVIDE, 0, m, &cBinop_KiSzdDyk_sendMessage);
}

void Heavy_WSTD_3Q::cCast_JHRznFob_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cZIfeP4o_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_KiSzdDyk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_U0MJ5eQF, HV_BINOP_MULTIPLY, 1, m, &cBinop_U0MJ5eQF_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_U0MJ5eQF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_mMosm3GQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ojg03nMo_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_NZpl86ZM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_NkCjRut2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cUnop_G5oH0keu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_WcowehXe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_aV5rPIh9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_NAiBLmCh_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_NAiBLmCh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_U0MJ5eQF, HV_BINOP_MULTIPLY, 0, m, &cBinop_U0MJ5eQF_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_SMIknlPr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_qnYRv2Bu_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_qnYRv2Bu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_21CCQBmm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_4z97KXjB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_POGMUVFH, HV_BINOP_MULTIPLY, 1, m, &cBinop_POGMUVFH_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_T44wpKO5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_tsO9ErsD_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_tsO9ErsD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_4z97KXjB_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_7zPys2Yj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_ihBGA6oT_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_ihBGA6oT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_kKuAyGqr, HV_BINOP_MULTIPLY, 1, m, &cBinop_kKuAyGqr_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_jlU6eZBQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_BZKo0L0j, HV_BINOP_MULTIPLY, 1, m, &cBinop_BZKo0L0j_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_qwi7Pt9s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_epvkvavV_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_epvkvavV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_jlU6eZBQ_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_8p4WSCoU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_j9zOLSae, 1, m, &cVar_j9zOLSae_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_T1sNIVSm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_23NuwJGU, HV_BINOP_MULTIPLY, 1, m, &cBinop_23NuwJGU_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_ZITkuK73_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_oxKL5mrE_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_oxKL5mrE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SkghAP3Z, HV_BINOP_MULTIPLY, 1, m, &cBinop_SkghAP3Z_sendMessage);
}

void Heavy_WSTD_3Q::cVar_j9zOLSae_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jiMs0sm4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_SpYQcHH8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jtF7tQxx_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_aV5rPIh9_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_nPFNJE2h_sendMessage);
}

void Heavy_WSTD_3Q::cVar_gyVuhWRb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_SMIknlPr_sendMessage);
}

void Heavy_WSTD_3Q::cCast_ojg03nMo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_G5oH0keu_sendMessage);
}

void Heavy_WSTD_3Q::cCast_mMosm3GQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_NZpl86ZM_sendMessage);
}

void Heavy_WSTD_3Q::cSend_NkCjRut2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_84f1WgBr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_WcowehXe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_bZ3lviQz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_cIr1deFb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_H1oaWckb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_21CCQBmm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_0BUTaUF3_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_0BUTaUF3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zwmXu7pz, HV_BINOP_MULTIPLY, 1, m, &cBinop_zwmXu7pz_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_zwmXu7pz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_E1tM3HqH_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_E1tM3HqH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_cIr1deFb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_jiMs0sm4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_kTVepVpH_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_kTVepVpH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wllcsppm_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_AkBm9SCM_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_n5fbj6ny_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_iKQCvgO2_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4hVnkssQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rT9y8XXn_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_POGMUVFH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LBIzB4kt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_kKuAyGqr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_c9e0ptyd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_BZKo0L0j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XHpz13iz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_23NuwJGU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3E7mWLtU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_SkghAP3Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_I3ZCCm81_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_UT20jlGM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_gyVuhWRb, 1, m, &cVar_gyVuhWRb_sendMessage);
}

void Heavy_WSTD_3Q::cCast_ESIZ2sUv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_SpYQcHH8, 0, m, &cVar_SpYQcHH8_sendMessage);
}

void Heavy_WSTD_3Q::cCast_iKQCvgO2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_BZKo0L0j, HV_BINOP_MULTIPLY, 0, m, &cBinop_BZKo0L0j_sendMessage);
}

void Heavy_WSTD_3Q::cCast_wllcsppm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_3Q::cCast_rT9y8XXn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_POGMUVFH, HV_BINOP_MULTIPLY, 0, m, &cBinop_POGMUVFH_sendMessage);
}

void Heavy_WSTD_3Q::cCast_n5fbj6ny_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_23NuwJGU, HV_BINOP_MULTIPLY, 0, m, &cBinop_23NuwJGU_sendMessage);
}

void Heavy_WSTD_3Q::cCast_4hVnkssQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_kKuAyGqr, HV_BINOP_MULTIPLY, 0, m, &cBinop_kKuAyGqr_sendMessage);
}

void Heavy_WSTD_3Q::cCast_AkBm9SCM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SkghAP3Z, HV_BINOP_MULTIPLY, 0, m, &cBinop_SkghAP3Z_sendMessage);
}

void Heavy_WSTD_3Q::cCast_jtF7tQxx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_gyVuhWRb, 0, m, &cVar_gyVuhWRb_sendMessage);
}

void Heavy_WSTD_3Q::cCast_nPFNJE2h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_j9zOLSae, 0, m, &cVar_j9zOLSae_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_GjY8PWFJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_cLjnPYh6, 1, m, &cIf_cLjnPYh6_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_Ct7WxLd1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_dyPFgaSg, m);
}

void Heavy_WSTD_3Q::cBinop_tCZRcDbM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Ct7WxLd1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_OyC66tCa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_cLjnPYh6, 0, m, &cIf_cLjnPYh6_sendMessage);
}

void Heavy_WSTD_3Q::cVar_c3EjjtDJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_G9L3U8Pw, HV_BINOP_DIVIDE, 0, m, &cBinop_G9L3U8Pw_sendMessage);
}

void Heavy_WSTD_3Q::cVar_nigP5AHU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3HP2922f, HV_BINOP_DIVIDE, 1, m, &cBinop_3HP2922f_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_G9L3U8Pw, HV_BINOP_DIVIDE, 1, m, &cBinop_G9L3U8Pw_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_mZO75YKS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_RIUKEGwn, HV_BINOP_DIVIDE, 0, m, &cBinop_RIUKEGwn_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_K4BUwHSx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_RIUKEGwn, HV_BINOP_DIVIDE, 1, m, &cBinop_RIUKEGwn_sendMessage);
}

void Heavy_WSTD_3Q::cCast_VoO3bGyn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3HP2922f, HV_BINOP_DIVIDE, 0, m, &cBinop_3HP2922f_sendMessage);
}

void Heavy_WSTD_3Q::cCast_UUiFobBH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_c3EjjtDJ, 0, m, &cVar_c3EjjtDJ_sendMessage);
}

void Heavy_WSTD_3Q::cCast_q7u0sdFU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_nigP5AHU, 0, m, &cVar_nigP5AHU_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_3HP2922f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_mZO75YKS_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_G9L3U8Pw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_K4BUwHSx_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_RIUKEGwn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_jbN8PSny_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_dBQhMQAR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.313f, 0, m, &cBinop_4PskShxY_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_7pHKssq4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.313f, 0, m, &cBinop_Wo8dHMwS_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_jbN8PSny_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_7pHKssq4_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Wo8dHMwS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_dBQhMQAR_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_4PskShxY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Td0lJQ4U_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_44CAmjBm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "highvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_JGwP8Hhw_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_QknMIXvM_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_U8jaekWw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_JGwP8Hhw_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_QknMIXvM_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_QC4k6eCM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "lowvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_JGwP8Hhw_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_QknMIXvM_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_TQeryeUs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midfreq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_JGwP8Hhw_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_QknMIXvM_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_Td0lJQ4U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_JGwP8Hhw_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_QknMIXvM_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_Ac2rBXyB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1337.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_rDjJvoqQ, 0, m, &cVar_rDjJvoqQ_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_Z7eIuMof_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_CnUPiurH, 0, m, &cVar_CnUPiurH_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_7B9LKYpT, 0, m, &cVar_7B9LKYpT_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_uYa5JVze, 0, m, &cVar_uYa5JVze_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_XXn8Ns9d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_CnUPiurH, 0, m, &cVar_CnUPiurH_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_OzaoSsDR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_7B9LKYpT, 0, m, &cVar_7B9LKYpT_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_mVHThkoR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_uYa5JVze, 0, m, &cVar_uYa5JVze_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_LQ3JNiqX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_acSufeIf, 0, m, &cVar_acSufeIf_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_6zftkQXq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FijjeMkQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mlTaHp01_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_2mVAzorM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xH9CtVR9_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QqsjobJw_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fIiKsHjQ_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_9fCnH5FS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QQqGjEIB_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_m5cyf9X1_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_XqL3qy3r_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_G5MJhm5u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_29LEr7xW_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_akcZn96L_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2magoOlC_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_zfcdI0NM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ITVaTz73_sendMessage(_c, 0, m);
  cMsg_S5V7eJsV_sendMessage(_c, 0, m);
  cMsg_PCBZPRMn_sendMessage(_c, 0, m);
  cMsg_rOsRYCow_sendMessage(_c, 0, m);
  cMsg_9Yw6VBnp_sendMessage(_c, 0, m);
  cMsg_soBsNfgR_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_B4Em57Rk, 0, m, &cVar_B4Em57Rk_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_acSufeIf, 0, m, &cVar_acSufeIf_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_4K8tStRN, 0, m, &cVar_4K8tStRN_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_lXSyxDqU, 0, m, &cVar_lXSyxDqU_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_uIHfeTXB, 0, m, &cVar_uIHfeTXB_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_SpYQcHH8, 0, m, &cVar_SpYQcHH8_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_qeof1ydL, 0, m, &cVar_qeof1ydL_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_NHY5vA2w, 0, m, &cVar_NHY5vA2w_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_aGqYbN1t, 0, m, &cVar_aGqYbN1t_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_YlWGGkCd, 0, m, &cVar_YlWGGkCd_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_bWMlKl5R, 0, m, &cVar_bWMlKl5R_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_dnF6lza1, 0, m, &cVar_dnF6lza1_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_gdffGTSn, 0, m, &cVar_gdffGTSn_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_tjxfxoLs, 0, m, &cVar_tjxfxoLs_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_owGWMraE, 0, m, &cVar_owGWMraE_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_lj9hcjWi, 0, m, &cVar_lj9hcjWi_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ODMbZyyY, 0, m, &cVar_ODMbZyyY_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_hmFHMTtO, 0, m, &cVar_hmFHMTtO_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Q0FDSOju, 0, m, &cVar_Q0FDSOju_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_GJtktxPc, 0, m, &cVar_GJtktxPc_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_1SFM0sZC, 0, m, &cVar_1SFM0sZC_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_XBPcIUNx, 0, m, &cVar_XBPcIUNx_sendMessage);
  cMsg_Z7eIuMof_sendMessage(_c, 0, m);
  cMsg_Ac2rBXyB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cReceive_y7Be9h03_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_J6Ll8HX6, HV_BINOP_MULTIPLY, 0, m, &cBinop_J6Ll8HX6_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_9jfojMPi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_TrKXQrV8_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_Ahr547Cm_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_wccudksg_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_tafOSmxl_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_ZFMVHSmV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_mGOmJZOm_sendMessage);
  cMsg_buHuBSZ1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cReceive_c0qv7GiA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_aA2DQkwD, HV_BINOP_MULTIPLY, 0, m, &cBinop_aA2DQkwD_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_dEPcIhhh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_zaGSu8UV_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_9iEpcFni_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3ZdPl3GC, HV_BINOP_MULTIPLY, 1, m, &cBinop_3ZdPl3GC_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_wgizh9S9_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_t6QGABcM_sendMessage);
  cMsg_P3NziZmr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cReceive_OayPJgmq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qfDWNpzl, HV_BINOP_MULTIPLY, 0, m, &cBinop_qfDWNpzl_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_3ZR9zThJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Z6PZwTyv_sendMessage(_c, 0, m);
  cMsg_yk0VrdPe_sendMessage(_c, 0, m);
  cMsg_4O3KTQoA_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_GHYdZM0m_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_XdkE8FFW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_DC9KjZlK_sendMessage);
  cMsg_XyRDfCkL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cReceive_l0Xnx72M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_uIHfeTXB, 0, m, &cVar_uIHfeTXB_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_pNbuAX6V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1pd26Sku_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_KGLsCIlo_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_DhE2lKiy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mOtr4obB_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_v5r3gwkt_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZDlx9afM_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_kGJ0rgCI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Jnj0ULav_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MoO7K8Qm_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vkFnRpPB_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_Je01cXd2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LkWH505O_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_yy1Yd4tg_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_V7MtnjS8_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_srOGlSqY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8edbncJ0, HV_BINOP_MULTIPLY, 0, m, &cBinop_8edbncJ0_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_LKiZnwmr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_eQewMhjt_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_8T4aSlif_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_qBbkcvzu_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_5QtkMUYs_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_QidyW0oS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_YbB86tSP_sendMessage);
  cMsg_PZj9eQN3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cReceive_prEH5FJT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5tW97S2V, HV_BINOP_MULTIPLY, 0, m, &cBinop_5tW97S2V_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_tRdFdGEZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_BSNYzVQF_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_nyDmQlSM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DQzMzmPt, HV_BINOP_MULTIPLY, 1, m, &cBinop_DQzMzmPt_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_2xmsbxWb_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_3Qe3vQRY_sendMessage);
  cMsg_ka4iLuZm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cReceive_84f1WgBr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zwmXu7pz, HV_BINOP_MULTIPLY, 0, m, &cBinop_zwmXu7pz_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_bZ3lviQz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_T44wpKO5_sendMessage(_c, 0, m);
  cMsg_7zPys2Yj_sendMessage(_c, 0, m);
  cMsg_qwi7Pt9s_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_T1sNIVSm_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_H1oaWckb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_8p4WSCoU_sendMessage);
  cMsg_ZITkuK73_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cReceive_TnGy30h2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_rDjJvoqQ, 0, m, &cVar_rDjJvoqQ_sendMessage);
}




/*
 * Context Process Implementation
 */

int Heavy_WSTD_3Q::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6, Bf7, Bf8, Bf9;

  // input and output vars
  hv_bufferf_t O0, O1, O2, O3, O4, O5;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));
    __hv_zero_f(VOf(O2));
    __hv_zero_f(VOf(O3));
    __hv_zero_f(VOf(O4));
    __hv_zero_f(VOf(O5));

    // process all signal functions
    __hv_line_f(&sLine_DNpyMB7R, VOf(Bf0));
    __hv_line_f(&sLine_0blVlLOw, VOf(Bf1));
    __hv_line_f(&sLine_eurLKY2Z, VOf(Bf2));
    __hv_line_f(&sLine_kfwYqmA1, VOf(Bf3));
    __hv_line_f(&sLine_zsBPQua4, VOf(Bf4));
    __hv_biquad_f(&sBiquad_s_mtdP2jhs, VIf(I0), VIf(Bf0), VIf(Bf1), VIf(Bf2), VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_zhgZtQ2W, VOf(Bf3));
    __hv_mul_f(VIf(Bf4), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_1GCVzIqb, VOf(Bf4));
    __hv_zero_f(VOf(Bf2));
    __hv_line_f(&sLine_ZAkNXRa6, VOf(Bf1));
    __hv_line_f(&sLine_KubcXbeF, VOf(Bf0));
    __hv_line_f(&sLine_H79c9aht, VOf(Bf5));
    __hv_biquad_f(&sBiquad_s_zWyi7Rep, VIf(I0), VIf(Bf4), VIf(Bf2), VIf(Bf1), VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_HRdlncO2, VOf(Bf0));
    __hv_mul_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_line_f(&sLine_sAgng0iT, VOf(Bf5));
    __hv_line_f(&sLine_ppEL1XyF, VOf(Bf1));
    __hv_line_f(&sLine_WvjXqdXC, VOf(Bf2));
    __hv_line_f(&sLine_rlQZIcjW, VOf(Bf4));
    __hv_line_f(&sLine_JKX0mrxJ, VOf(Bf6));
    __hv_biquad_f(&sBiquad_s_A4sXvaF3, VIf(I0), VIf(Bf5), VIf(Bf1), VIf(Bf2), VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_Ba4nG8Mq, VOf(Bf4));
    __hv_mul_f(VIf(Bf6), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_VkDfxStq, VOf(Bf6));
    __hv_line_f(&sLine_fLXXvTSf, VOf(Bf2));
    __hv_line_f(&sLine_s30p1b5a, VOf(Bf1));
    __hv_line_f(&sLine_OS8zYqEm, VOf(Bf5));
    __hv_line_f(&sLine_OU8mXmXc, VOf(Bf7));
    __hv_biquad_f(&sBiquad_s_uEVAijHu, VIf(I1), VIf(Bf6), VIf(Bf2), VIf(Bf1), VIf(Bf5), VIf(Bf7), VOf(Bf7));
    __hv_varread_f(&sVarf_YEEastwb, VOf(Bf5));
    __hv_mul_f(VIf(Bf7), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_UnsnZzw6, VOf(Bf7));
    __hv_zero_f(VOf(Bf1));
    __hv_line_f(&sLine_ooxwna9B, VOf(Bf2));
    __hv_line_f(&sLine_h5pqxf1E, VOf(Bf6));
    __hv_line_f(&sLine_OkRJNBLz, VOf(Bf8));
    __hv_biquad_f(&sBiquad_s_Q69k9Q22, VIf(I1), VIf(Bf7), VIf(Bf1), VIf(Bf2), VIf(Bf6), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_dyPFgaSg, VOf(Bf6));
    __hv_mul_f(VIf(Bf8), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_rfaGlJGj, VOf(Bf8));
    __hv_line_f(&sLine_jARsFh7u, VOf(Bf2));
    __hv_line_f(&sLine_3qpsIqbD, VOf(Bf1));
    __hv_line_f(&sLine_5EPooetf, VOf(Bf7));
    __hv_line_f(&sLine_v9eBZXEQ, VOf(Bf9));
    __hv_biquad_f(&sBiquad_s_5k4SJeIi, VIf(I1), VIf(Bf8), VIf(Bf2), VIf(Bf1), VIf(Bf7), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_zZxFxKJJ, VOf(Bf7));
    __hv_mul_f(VIf(Bf9), VIf(Bf7), VOf(Bf7));
    __hv_add_f(VIf(Bf0), VIf(O2), VOf(O2));
    __hv_add_f(VIf(Bf7), VIf(O5), VOf(O5));
    __hv_add_f(VIf(Bf3), VIf(O0), VOf(O0));
    __hv_add_f(VIf(Bf6), VIf(O3), VOf(O3));
    __hv_add_f(VIf(Bf5), VIf(O1), VOf(O1));
    __hv_add_f(VIf(Bf4), VIf(O4), VOf(O4));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
    __hv_store_f(outputBuffers[2]+n, VIf(O2));
    __hv_store_f(outputBuffers[3]+n, VIf(O3));
    __hv_store_f(outputBuffers[4]+n, VIf(O4));
    __hv_store_f(outputBuffers[5]+n, VIf(O5));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_WSTD_3Q::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 6 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(6*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);
  bOut[2] = outputBuffers+(2*n4);
  bOut[3] = outputBuffers+(3*n4);
  bOut[4] = outputBuffers+(4*n4);
  bOut[5] = outputBuffers+(5*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_WSTD_3Q::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 6 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(6*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  
  // interleave the heavy output into the output buffer
  for (int i = 0; i < 6; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+6*j] = bOut[i*n4+j];
    }
  }

  return n;
}
